#include "chipmunk.h"


// Name: (cpMomentForCircle)  Return Type: (cpFloat)  Arguments: (cpFloat m, cpFloat r1, cpFloat r2, cpVect offset)  - Calculate the moment of inertia for a circle.
/// Calculate the moment of inertia for a circle.
cpFloat PB_cpMomentForCircle(cpFloat m, cpFloat r1, cpFloat r2, cpVect *offset)
{
     return cpMomentForCircle(m, r1, r2, *offset);
}

// Name: (cpAreaForCircle)  Return Type: (cpFloat)  Arguments: (cpFloat r1, cpFloat r2)  - Calculate area of a hollow circle.
/// Calculate area of a hollow circle.
cpFloat PB_cpAreaForCircle(cpFloat r1, cpFloat r2)
{
     return cpAreaForCircle(r1, r2);
}

// Name: (cpMomentForSegment)  Return Type: (cpFloat)  Arguments: (cpFloat m, cpVect a, cpVect b)  - Calculate the moment of inertia for a line segment.
/// Calculate the moment of inertia for a line segment.
cpFloat PB_cpMomentForSegment(cpFloat m, cpVect *a, cpVect *b)
{
     return cpMomentForSegment(m, *a, *b);
}

// Name: (cpAreaForSegment)  Return Type: (cpFloat)  Arguments: (cpVect a, cpVect b, cpFloat r)  - Calculate the area of a fattened (capsule shaped) line segment.
/// Calculate the area of a fattened (capsule shaped) line segment.
cpFloat PB_cpAreaForSegment(cpVect *a, cpVect *b, cpFloat r)
{
     return cpAreaForSegment(*a, *b, r);
}

// Name: (cpMomentForPoly)  Return Type: (cpFloat)  Arguments: (cpFloat m, int numVerts, cpVect *verts, cpVect offset)  - Calculate the moment of inertia for a solid polygon shape assuming it's center of gravity is at it's centroid. The offset is added to each vertex.
/// Calculate the moment of inertia for a solid polygon shape assuming it's center of gravity is at it's centroid. The offset is added to each vertex.
cpFloat PB_cpMomentForPoly(cpFloat m, int numVerts, cpVect *verts, cpVect *offset)
{
     return cpMomentForPoly(m, numVerts, verts, *offset);
}

// Name: (cpAreaForPoly)  Return Type: (cpFloat)  Arguments: (int numVerts, cpVect *verts)  - Calculate the signed area of a polygon. A Clockwise winding gives positive area.
/// Calculate the signed area of a polygon. A Clockwise winding gives positive area.
cpFloat PB_cpAreaForPoly(int numVerts, cpVect *verts)
{
     return cpAreaForPoly(numVerts, verts);
}

// Name: (cpCentroidForPoly)  Return Type: (cpVect)  Arguments: (int numVerts, cpVect *verts)  - Calculate the natural centroid of a polygon.
/// Calculate the natural centroid of a polygon.
void PB_cpCentroidForPoly(cpVect *result, int numVerts, cpVect *verts)
{
     *result = cpCentroidForPoly(numVerts, verts);
}

// Name: (cpRecenterPoly)  Return Type: (void)  Arguments: (int numVerts, cpVect *verts)  - Center the polygon on the origin. (Subtracts the centroid of the polygon from each vertex)
/// Center the polygon on the origin. (Subtracts the centroid of the polygon from each vertex)
void PB_cpRecenterPoly(int numVerts, cpVect *verts)
{
     cpRecenterPoly(numVerts, verts);
}

// Name: (cpMomentForBox)  Return Type: (cpFloat)  Arguments: (cpFloat m, cpFloat width, cpFloat height)  - Calculate the moment of inertia for a solid box.
/// Calculate the moment of inertia for a solid box.
cpFloat PB_cpMomentForBox(cpFloat m, cpFloat width, cpFloat height)
{
     return cpMomentForBox(m, width, height);
}

// Name: (cpMomentForBox2)  Return Type: (cpFloat)  Arguments: (cpFloat m, cpBB box)  - Calculate the moment of inertia for a solid box.
/// Calculate the moment of inertia for a solid box.
cpFloat PB_cpMomentForBox2(cpFloat m, cpBB *box)
{
     return cpMomentForBox2(m, *box);
}

// Name: (cpConvexHull)  Return Type: (int)  Arguments: (int count, cpVect *verts, cpVect *result, int *first, cpFloat tol)  - Calculate the convex hull of a given set of points. Returns the count of points in the hull.
/// Calculate the convex hull of a given set of points. Returns the count of points in the hull.
int PB_cpConvexHull(int count, cpVect *verts, cpVect *result, int *first, cpFloat tol)
{
     return cpConvexHull(count, verts, result, first, tol);
}

// Name: (cpfmax)  Return Type: (cpFloat)  Arguments: (cpFloat a, cpFloat b)  - Return the max of two cpFloats.
/// Return the max of two cpFloats.
cpFloat PB_cpfmax(cpFloat a, cpFloat b)
{
     return cpfmax(a, b);
}

// Name: (cpfmin)  Return Type: (cpFloat)  Arguments: (cpFloat a, cpFloat b)  - Return the min of two cpFloats.
/// Return the min of two cpFloats.
cpFloat PB_cpfmin(cpFloat a, cpFloat b)
{
     return cpfmin(a, b);
}

// Name: (cpfabs)  Return Type: (cpFloat)  Arguments: (cpFloat f)  - Return the absolute value of a cpFloat.
/// Return the absolute value of a cpFloat.
cpFloat PB_cpfabs(cpFloat f)
{
     return cpfabs(f);
}

// Name: (cpfclamp)  Return Type: (cpFloat)  Arguments: (cpFloat f, cpFloat min, cpFloat max)  - Clamp f to be between min and max.
/// Clamp f to be between min and max.
cpFloat PB_cpfclamp(cpFloat f, cpFloat min, cpFloat max)
{
     return cpfclamp(f, min, max);
}

// Name: (cpfclamp01)  Return Type: (cpFloat)  Arguments: (cpFloat f)  - Clamp f to be between 0 and 1.
/// Clamp f to be between 0 and 1.
cpFloat PB_cpfclamp01(cpFloat f)
{
     return cpfclamp01(f);
}

// Name: (cpflerp)  Return Type: (cpFloat)  Arguments: (cpFloat f1, cpFloat f2, cpFloat t)  - Linearly interpolate (or extrapolate) between f1 and f2 by t percent.
/// Linearly interpolate (or extrapolate) between f1 and f2 by t percent.
cpFloat PB_cpflerp(cpFloat f1, cpFloat f2, cpFloat t)
{
     return cpflerp(f1, f2, t);
}

// Name: (cpflerpconst)  Return Type: (cpFloat)  Arguments: (cpFloat f1, cpFloat f2, cpFloat d)  - Linearly interpolate from f1 to f2 by no more than d.
/// Linearly interpolate from f1 to f2 by no more than d.
cpFloat PB_cpflerpconst(cpFloat f1, cpFloat f2, cpFloat d)
{
     return cpflerpconst(f1, f2, d);
}

// Name: (cpArbiterTotalImpulse)  Return Type: (cpVect)  Arguments: (cpArbiter *arb)  - Calculate the total impulse that was applied by this arbiter.
/// Calculate the total impulse that was applied by this arbiter.
void PB_cpArbiterTotalImpulse(cpVect *result, cpArbiter *arb)
{
     *result = cpArbiterTotalImpulse(arb);
}

// Name: (cpArbiterTotalImpulseWithFriction)  Return Type: (cpVect)  Arguments: (cpArbiter *arb)  - Calculate the total impulse including the friction that was applied by this arbiter.
/// Calculate the total impulse including the friction that was applied by this arbiter.
void PB_cpArbiterTotalImpulseWithFriction(cpVect *result, cpArbiter *arb)
{
     *result = cpArbiterTotalImpulseWithFriction(arb);
}

// Name: (cpArbiterTotalKE)  Return Type: (cpFloat)  Arguments: (cpArbiter *arb)  - Calculate the amount of energy lost in a collision including static, but not dynamic friction.
/// Calculate the amount of energy lost in a collision including static, but not dynamic friction.
cpFloat PB_cpArbiterTotalKE(cpArbiter *arb)
{
     return cpArbiterTotalKE(arb);
}

// Name: (cpArbiterIgnore)  Return Type: (void)  Arguments: (cpArbiter *arb)  - Causes a collision pair to be ignored as if you returned false from a begin callback.
/// Causes a collision pair to be ignored as if you returned false from a begin callback.
void PB_cpArbiterIgnore(cpArbiter *arb)
{
     cpArbiterIgnore(arb);
}

// Name: (cpArbiterGetShapes)  Return Type: (void)  Arguments: (cpArbiter *arb, cpShape **a, cpShape **b)  - Return the colliding shapes involved for this arbiter.
/// Return the colliding shapes involved for this arbiter.
void PB_cpArbiterGetShapes(cpArbiter *arb, cpShape **a, cpShape **b)
{
     cpArbiterGetShapes(arb, a, b);
}

// Name: (cpArbiterGetBodies)  Return Type: (void)  Arguments: (cpArbiter *arb, cpBody **a, cpBody **b)  - Return the colliding bodies involved for this arbiter.
/// Return the colliding bodies involved for this arbiter.
void PB_cpArbiterGetBodies(cpArbiter *arb, cpBody **a, cpBody **b)
{
     cpArbiterGetBodies(arb, a, b);
}

// Name: (cpArbiterGetContactPointSet)  Return Type: (cpContactPointSet)  Arguments: (cpArbiter *arb)  - Return a contact set from an arbiter.
/// Return a contact set from an arbiter.
void PB_cpArbiterGetContactPointSet(cpContactPointSet *result, cpArbiter *arb)
{
     *result = cpArbiterGetContactPointSet(arb);
}

// Name: (cpArbiterIsFirstContact)  Return Type: (cpBool)  Arguments: (cpArbiter *arb)  - Returns true if this is the first step a pair of objects started colliding.
/// Returns true if this is the first step a pair of objects started colliding.
cpBool PB_cpArbiterIsFirstContact(cpArbiter *arb)
{
     return cpArbiterIsFirstContact(arb);
}

// Name: (cpArbiterGetCount)  Return Type: (int)  Arguments: (cpArbiter *arb)  - Get the number of contact points for this arbiter.
/// Get the number of contact points for this arbiter.
int PB_cpArbiterGetCount(cpArbiter *arb)
{
     return cpArbiterGetCount(arb);
}

// Name: (cpArbiterGetNormal)  Return Type: (cpVect)  Arguments: (cpArbiter *arb, int i)  - Get the normal of the ith contact point.
/// Get the normal of the ith contact point.
void PB_cpArbiterGetNormal(cpVect *result, cpArbiter *arb, int i)
{
     *result = cpArbiterGetNormal(arb, i);
}

// Name: (cpArbiterGetPoint)  Return Type: (cpVect)  Arguments: (cpArbiter *arb, int i)  - Get the position of the ith contact point.
/// Get the position of the ith contact point.
void PB_cpArbiterGetPoint(cpVect *result, cpArbiter *arb, int i)
{
     *result = cpArbiterGetPoint(arb, i);
}

// Name: (cpArbiterGetDepth)  Return Type: (cpFloat)  Arguments: (cpArbiter *arb, int i)  - Get the depth of the ith contact point.
/// Get the depth of the ith contact point.
cpFloat PB_cpArbiterGetDepth(cpArbiter *arb, int i)
{
     return cpArbiterGetDepth(arb, i);
}

// Name: (cpBBNew)  Return Type: (cpBB)  Arguments: (cpFloat l, cpFloat b, cpFloat r, cpFloat t)  - Convenience constructor for cpBB structs.
/// Convenience constructor for cpBB structs.
void PB_cpBBNew(cpBB *result, cpFloat l, cpFloat b, cpFloat r, cpFloat t)
{
     *result = cpBBNew(l, b, r, t);
}

// Name: (cpBBNewForCircle)  Return Type: (cpBB)  Arguments: (cpVect p, cpFloat r)  - Constructs a cpBB for a circle with the given position and radius.
/// Constructs a cpBB for a circle with the given position and radius.
void PB_cpBBNewForCircle(cpBB *result, cpVect *p, cpFloat r)
{
     *result = cpBBNewForCircle(*p, r);
}

// Name: (cpBBIntersects)  Return Type: (cpBool)  Arguments: (cpBB a, cpBB b)  - Returns true if a and b intersect.
/// Returns true if a and b intersect.
cpBool PB_cpBBIntersects(cpBB *a, cpBB *b)
{
     return cpBBIntersects(*a, *b);
}

// Name: (cpBBContainsBB)  Return Type: (cpBool)  Arguments: (cpBB bb, cpBB other)  - Returns true if other lies completely within bb.
/// Returns true if other lies completely within bb.
cpBool PB_cpBBContainsBB(cpBB *bb, cpBB *other)
{
     return cpBBContainsBB(*bb, *other);
}

// Name: (cpBBContainsVect)  Return Type: (cpBool)  Arguments: (cpBB bb, cpVect v)  - Returns true if bb contains v.
/// Returns true if bb contains v.
cpBool PB_cpBBContainsVect(cpBB *bb, cpVect *v)
{
     return cpBBContainsVect(*bb, *v);
}

// Name: (cpBBMerge)  Return Type: (cpBB)  Arguments: (cpBB a, cpBB b)  - Returns a bounding box that holds both bounding boxes.
/// Returns a bounding box that holds both bounding boxes.
void PB_cpBBMerge(cpBB *result, cpBB *a, cpBB *b)
{
     *result = cpBBMerge(*a, *b);
}

// Name: (cpBBExpand)  Return Type: (cpBB)  Arguments: (cpBB bb, cpVect v)  - Returns a bounding box that holds both bb and v.
/// Returns a bounding box that holds both bb and v.
void PB_cpBBExpand(cpBB *result, cpBB *bb, cpVect *v)
{
     *result = cpBBExpand(*bb, *v);
}

// Name: (cpBBArea)  Return Type: (cpFloat)  Arguments: (cpBB bb)  - Returns the area of the bounding box.
/// Returns the area of the bounding box.
cpFloat PB_cpBBArea(cpBB *bb)
{
     return cpBBArea(*bb);
}

// Name: (cpBBMergedArea)  Return Type: (cpFloat)  Arguments: (cpBB a, cpBB b)  - Merges a and b and returns the area of the merged bounding box.
/// Merges a and b and returns the area of the merged bounding box.
cpFloat PB_cpBBMergedArea(cpBB *a, cpBB *b)
{
     return cpBBMergedArea(*a, *b);
}

// Name: (cpBBSegmentQuery)  Return Type: (cpFloat)  Arguments: (cpBB bb, cpVect a, cpVect b)  - Returns the fraction along the segment query the cpBB is hit. Returns INFINITY if it doesn't hit.
/// Returns the fraction along the segment query the cpBB is hit. Returns INFINITY if it doesn't hit.
cpFloat PB_cpBBSegmentQuery(cpBB *bb, cpVect *a, cpVect *b)
{
     return cpBBSegmentQuery(*bb, *a, *b);
}

// Name: (cpBBIntersectsSegment)  Return Type: (cpBool)  Arguments: (cpBB bb, cpVect a, cpVect b)  - Return true if the bounding box intersects the line segment with ends a and b.
/// Return true if the bounding box intersects the line segment with ends a and b.
cpBool PB_cpBBIntersectsSegment(cpBB *bb, cpVect *a, cpVect *b)
{
     return cpBBIntersectsSegment(*bb, *a, *b);
}

// Name: (cpBBClampVect)  Return Type: (cpVect)  Arguments: (cpBB bb, cpVect v)  - Clamp a vector to a bounding box.
/// Clamp a vector to a bounding box.
void PB_cpBBClampVect(cpVect *result, cpBB *bb, cpVect *v)
{
     *result = cpBBClampVect(*bb, *v);
}

// Name: (cpBBWrapVect)  Return Type: (cpVect)  Arguments: (cpBB bb, cpVect v)  - Wrap a vector to a bounding box.
/// Wrap a vector to a bounding box.
void PB_cpBBWrapVect(cpVect *result, cpBB *bb, cpVect *v)
{
     *result = cpBBWrapVect(*bb, *v);
}

// Name: (cpBodyAlloc)  Return Type: (cpBody*)  Arguments: (void)  - Allocate a cpBody.
/// Allocate a cpBody.
cpBody* PB_cpBodyAlloc(void )
{
     return cpBodyAlloc();
}

// Name: (cpBodyInit)  Return Type: (cpBody*)  Arguments: (cpBody *body, cpFloat m, cpFloat i)  - Initialize a cpBody.
/// Initialize a cpBody.
cpBody* PB_cpBodyInit(cpBody *body, cpFloat m, cpFloat i)
{
     return cpBodyInit(body, m, i);
}

// Name: (cpBodyNew)  Return Type: (cpBody*)  Arguments: (cpFloat m, cpFloat i)  - Allocate and initialize a cpBody.
/// Allocate and initialize a cpBody.
cpBody* PB_cpBodyNew(cpFloat m, cpFloat i)
{
     return cpBodyNew(m, i);
}

// Name: (cpBodyInitStatic)  Return Type: (cpBody*)  Arguments: (cpBody *body)  - Initialize a static cpBody.
/// Initialize a static cpBody.
cpBody* PB_cpBodyInitStatic(cpBody *body)
{
     return cpBodyInitStatic(body);
}

// Name: (cpBodyNewStatic)  Return Type: (cpBody*)  Arguments: (void)  - Allocate and initialize a static cpBody.
/// Allocate and initialize a static cpBody.
cpBody* PB_cpBodyNewStatic(void )
{
     return cpBodyNewStatic();
}

// Name: (cpBodyDestroy)  Return Type: (void)  Arguments: (cpBody *body)  - Destroy a cpBody.
/// Destroy a cpBody.
void PB_cpBodyDestroy(cpBody *body)
{
     cpBodyDestroy(body);
}

// Name: (cpBodyFree)  Return Type: (void)  Arguments: (cpBody *body)  - Destroy and free a cpBody.
/// Destroy and free a cpBody.
void PB_cpBodyFree(cpBody *body)
{
     cpBodyFree(body);
}

// Name: (cpBodySanityCheck)  Return Type: (void)  Arguments: (cpBody *body)  - Check that the properties of a body is sane. (Only in debug mode)
/// Check that the properties of a body is sane. (Only in debug mode)
void PB_cpBodySanityCheck(cpBody *body)
{
     cpBodySanityCheck(body);
}

// Name: (cpBodyActivate)  Return Type: (void)  Arguments: (cpBody *body)  - Wake up a sleeping or idle body.
/// Wake up a sleeping or idle body.
void PB_cpBodyActivate(cpBody *body)
{
     cpBodyActivate(body);
}

// Name: (cpBodyActivateStatic)  Return Type: (void)  Arguments: (cpBody *body, cpShape *filter)  - Wake up any sleeping or idle bodies touching a static body.
/// Wake up any sleeping or idle bodies touching a static body.
void PB_cpBodyActivateStatic(cpBody *body, cpShape *filter)
{
     cpBodyActivateStatic(body, filter);
}

// Name: (cpBodySleep)  Return Type: (void)  Arguments: (cpBody *body)  - Force a body to fall asleep immediately.
/// Force a body to fall asleep immediately.
void PB_cpBodySleep(cpBody *body)
{
     cpBodySleep(body);
}

// Name: (cpBodySleepWithGroup)  Return Type: (void)  Arguments: (cpBody *body, cpBody *group)  - Force a body to fall asleep immediately along with other bodies in a group.
/// Force a body to fall asleep immediately along with other bodies in a group.
void PB_cpBodySleepWithGroup(cpBody *body, cpBody *group)
{
     cpBodySleepWithGroup(body, group);
}

// Name: (cpBodyIsSleeping)  Return Type: (cpBool)  Arguments: (cpBody *body)  - Returns true if the body is sleeping.
/// Returns true if the body is sleeping.
cpBool PB_cpBodyIsSleeping(cpBody *body)
{
     return cpBodyIsSleeping(body);
}

// Name: (cpBodyIsStatic)  Return Type: (cpBool)  Arguments: (cpBody *body)  - Returns true if the body is static.
/// Returns true if the body is static.
cpBool PB_cpBodyIsStatic(cpBody *body)
{
     return cpBodyIsStatic(body);
}

// Name: (cpBodyIsRogue)  Return Type: (cpBool)  Arguments: (cpBody *body)  - Returns true if the body has not been added to a space.
/// Returns true if the body has not been added to a space.
cpBool PB_cpBodyIsRogue(cpBody *body)
{
     return cpBodyIsRogue(body);
}

// Name: (cpBodySetMass)  Return Type: (void)  Arguments: (cpBody *body, cpFloat m)  - Set the mass of a body.
/// Set the mass of a body.
void PB_cpBodySetMass(cpBody *body, cpFloat m)
{
     cpBodySetMass(body, m);
}

// Name: (cpBodySetMoment)  Return Type: (void)  Arguments: (cpBody *body, cpFloat i)  - Set the moment of a body.
/// Set the moment of a body.
void PB_cpBodySetMoment(cpBody *body, cpFloat i)
{
     cpBodySetMoment(body, i);
}

// Name: (cpBodySetPos)  Return Type: (void)  Arguments: (cpBody *body, cpVect pos)  - Set the position of a body.
/// Set the position of a body.
void PB_cpBodySetPos(cpBody *body, cpVect *pos)
{
     cpBodySetPos(body, *pos);
}

// Name: (cpBodySetAngle)  Return Type: (void)  Arguments: (cpBody *body, cpFloat a)  - Set the angle of a body.
/// Set the angle of a body.
void PB_cpBodySetAngle(cpBody *body, cpFloat a)
{
     cpBodySetAngle(body, a);
}

// Name: (cpBodyUpdateVelocity)  Return Type: (void)  Arguments: (cpBody *body, cpVect gravity, cpFloat damping, cpFloat dt)  - Default Integration functions.
/// Default Integration functions.
void PB_cpBodyUpdateVelocity(cpBody *body, cpVect *gravity, cpFloat damping, cpFloat dt)
{
     cpBodyUpdateVelocity(body, *gravity, damping, dt);
}

// Name: (cpBodyUpdatePosition)  Return Type: (void)  Arguments: (cpBody *body, cpFloat dt)  - 
/// 
void PB_cpBodyUpdatePosition(cpBody *body, cpFloat dt)
{
     cpBodyUpdatePosition(body, dt);
}

// Name: (cpBodyLocal2World)  Return Type: (cpVect)  Arguments: (cpBody *body, cpVect v)  - Convert body relative/local coordinates to absolute/world coordinates.
/// Convert body relative/local coordinates to absolute/world coordinates.
void PB_cpBodyLocal2World(cpVect *result, cpBody *body, cpVect *v)
{
     *result = cpBodyLocal2World(body, *v);
}

// Name: (cpBodyWorld2Local)  Return Type: (cpVect)  Arguments: (cpBody *body, cpVect v)  - Convert body absolute/world coordinates to  relative/local coordinates.
/// Convert body absolute/world coordinates to  relative/local coordinates.
void PB_cpBodyWorld2Local(cpVect *result, cpBody *body, cpVect *v)
{
     *result = cpBodyWorld2Local(body, *v);
}

// Name: (cpBodyResetForces)  Return Type: (void)  Arguments: (cpBody *body)  - Set the forces and torque or a body to zero.
/// Set the forces and torque or a body to zero.
void PB_cpBodyResetForces(cpBody *body)
{
     cpBodyResetForces(body);
}

// Name: (cpBodyApplyForce)  Return Type: (void)  Arguments: (cpBody *body, cpVect f, cpVect r)  - Apply an force (in world coordinates) to the body at a point relative to the center of gravity (also in world coordinates).
/// Apply an force (in world coordinates) to the body at a point relative to the center of gravity (also in world coordinates).
void PB_cpBodyApplyForce(cpBody *body, cpVect *f, cpVect *r)
{
     cpBodyApplyForce(body, *f, *r);
}

// Name: (cpBodyApplyImpulse)  Return Type: (void)  Arguments: (cpBody *body, cpVect j, cpVect r)  - Apply an impulse (in world coordinates) to the body at a point relative to the center of gravity (also in world coordinates).
/// Apply an impulse (in world coordinates) to the body at a point relative to the center of gravity (also in world coordinates).
void PB_cpBodyApplyImpulse(cpBody *body, cpVect *j, cpVect *r)
{
     cpBodyApplyImpulse(body, *j, *r);
}

// Name: (cpBodyGetVelAtWorldPoint)  Return Type: (cpVect)  Arguments: (cpBody *body, cpVect point)  - Get the velocity on a body (in world units) at a point on the body in world coordinates.
/// Get the velocity on a body (in world units) at a point on the body in world coordinates.
void PB_cpBodyGetVelAtWorldPoint(cpVect *result, cpBody *body, cpVect *point)
{
     *result = cpBodyGetVelAtWorldPoint(body, *point);
}

// Name: (cpBodyGetVelAtLocalPoint)  Return Type: (cpVect)  Arguments: (cpBody *body, cpVect point)  - Get the velocity on a body (in world units) at a point on the body in local coordinates.
/// Get the velocity on a body (in world units) at a point on the body in local coordinates.
void PB_cpBodyGetVelAtLocalPoint(cpVect *result, cpBody *body, cpVect *point)
{
     *result = cpBodyGetVelAtLocalPoint(body, *point);
}

// Name: (cpBodyKineticEnergy)  Return Type: (cpFloat)  Arguments: (cpBody *body)  - Get the kinetic energy of a body.
/// Get the kinetic energy of a body.
cpFloat PB_cpBodyKineticEnergy(cpBody *body)
{
     return cpBodyKineticEnergy(body);
}

// Name: (cpBodyEachShape)  Return Type: (void)  Arguments: (cpBody *body, cpBodyShapeIteratorFunc func, void *data)  - Call func once for each shape attached to body and added to the space.
/// Call func once for each shape attached to body and added to the space.
void PB_cpBodyEachShape(cpBody *body, cpBodyShapeIteratorFunc func, void *data)
{
     cpBodyEachShape(body, func, data);
}

// Name: (cpBodyEachConstraint)  Return Type: (void)  Arguments: (cpBody *body, cpBodyConstraintIteratorFunc func, void *data)  - Call func once for each constraint attached to body and added to the space.
/// Call func once for each constraint attached to body and added to the space.
void PB_cpBodyEachConstraint(cpBody *body, cpBodyConstraintIteratorFunc func, void *data)
{
     cpBodyEachConstraint(body, func, data);
}

// Name: (cpBodyEachArbiter)  Return Type: (void)  Arguments: (cpBody *body, cpBodyArbiterIteratorFunc func, void *data)  - Call func once for each arbiter that is currently active on the body.
/// Call func once for each arbiter that is currently active on the body.
void PB_cpBodyEachArbiter(cpBody *body, cpBodyArbiterIteratorFunc func, void *data)
{
     cpBodyEachArbiter(body, func, data);
}

// Name: (cpPolyShapeAlloc)  Return Type: (cpPolyShape*)  Arguments: (void)  - Allocate a polygon shape.
/// Allocate a polygon shape.
cpPolyShape* PB_cpPolyShapeAlloc(void )
{
     return cpPolyShapeAlloc();
}

// Name: (cpPolyShapeInit)  Return Type: (cpPolyShape*)  Arguments: (cpPolyShape *poly, cpBody *body, int numVerts, cpVect *verts, cpVect offset)  - Initialize a polygon shape.
/// Initialize a polygon shape.
cpPolyShape* PB_cpPolyShapeInit(cpPolyShape *poly, cpBody *body, int numVerts, cpVect *verts, cpVect *offset)
{
     return cpPolyShapeInit(poly, body, numVerts, verts, *offset);
}

// Name: (cpPolyShapeNew)  Return Type: (cpShape*)  Arguments: (cpBody *body, int numVerts, cpVect *verts, cpVect offset)  - Allocate and initialize a polygon shape.
/// Allocate and initialize a polygon shape.
cpShape* PB_cpPolyShapeNew(cpBody *body, int numVerts, cpVect *verts, cpVect *offset)
{
     return cpPolyShapeNew(body, numVerts, verts, *offset);
}

// Name: (cpBoxShapeInit)  Return Type: (cpPolyShape*)  Arguments: (cpPolyShape *poly, cpBody *body, cpFloat width, cpFloat height)  - Initialize a box shaped polygon shape.
/// Initialize a box shaped polygon shape.
cpPolyShape* PB_cpBoxShapeInit(cpPolyShape *poly, cpBody *body, cpFloat width, cpFloat height)
{
     return cpBoxShapeInit(poly, body, width, height);
}

// Name: (cpBoxShapeInit2)  Return Type: (cpPolyShape*)  Arguments: (cpPolyShape *poly, cpBody *body, cpBB box)  - Initialize an offset box shaped polygon shape.
/// Initialize an offset box shaped polygon shape.
cpPolyShape* PB_cpBoxShapeInit2(cpPolyShape *poly, cpBody *body, cpBB *box)
{
     return cpBoxShapeInit2(poly, body, *box);
}

// Name: (cpBoxShapeNew)  Return Type: (cpShape*)  Arguments: (cpBody *body, cpFloat width, cpFloat height)  - Allocate and initialize a box shaped polygon shape.
/// Allocate and initialize a box shaped polygon shape.
cpShape* PB_cpBoxShapeNew(cpBody *body, cpFloat width, cpFloat height)
{
     return cpBoxShapeNew(body, width, height);
}

// Name: (cpBoxShapeNew2)  Return Type: (cpShape*)  Arguments: (cpBody *body, cpBB box)  - Allocate and initialize an offset box shaped polygon shape.
/// Allocate and initialize an offset box shaped polygon shape.
cpShape* PB_cpBoxShapeNew2(cpBody *body, cpBB *box)
{
     return cpBoxShapeNew2(body, *box);
}

// Name: (cpPolyValidate)  Return Type: (cpBool)  Arguments: (cpVect *verts, int numVerts)  - Check that a set of vertexes is convex and has a clockwise winding.
/// Check that a set of vertexes is convex and has a clockwise winding.
cpBool PB_cpPolyValidate(cpVect *verts, int numVerts)
{
     return cpPolyValidate(verts, numVerts);
}

// Name: (cpPolyShapeGetNumVerts)  Return Type: (int)  Arguments: (cpShape *shape)  - Get the number of verts in a polygon shape.
/// Get the number of verts in a polygon shape.
int PB_cpPolyShapeGetNumVerts(cpShape *shape)
{
     return cpPolyShapeGetNumVerts(shape);
}

// Name: (cpPolyShapeGetVert)  Return Type: (cpVect)  Arguments: (cpShape *shape, int idx)  - Get the ith vertex of a polygon shape.
/// Get the ith vertex of a polygon shape.
void PB_cpPolyShapeGetVert(cpVect *result, cpShape *shape, int idx)
{
     *result = cpPolyShapeGetVert(shape, idx);
}

// Name: (cpShapeDestroy)  Return Type: (void)  Arguments: (cpShape *shape)  - Destroy a shape.
/// Destroy a shape.
void PB_cpShapeDestroy(cpShape *shape)
{
     cpShapeDestroy(shape);
}

// Name: (cpShapeFree)  Return Type: (void)  Arguments: (cpShape *shape)  - Destroy and Free a shape.
/// Destroy and Free a shape.
void PB_cpShapeFree(cpShape *shape)
{
     cpShapeFree(shape);
}

// Name: (cpShapeCacheBB)  Return Type: (cpBB)  Arguments: (cpShape *shape)  - Update, cache and return the bounding box of a shape based on the body it's attached to.
/// Update, cache and return the bounding box of a shape based on the body it's attached to.
void PB_cpShapeCacheBB(cpBB *result, cpShape *shape)
{
     *result = cpShapeCacheBB(shape);
}

// Name: (cpShapeUpdate)  Return Type: (cpBB)  Arguments: (cpShape *shape, cpVect pos, cpVect rot)  - Update, cache and return the bounding box of a shape with an explicit transformation.
/// Update, cache and return the bounding box of a shape with an explicit transformation.
void PB_cpShapeUpdate(cpBB *result, cpShape *shape, cpVect *pos, cpVect *rot)
{
     *result = cpShapeUpdate(shape, *pos, *rot);
}

// Name: (cpShapePointQuery)  Return Type: (cpBool)  Arguments: (cpShape *shape, cpVect p)  - Test if a point lies within a shape.
/// Test if a point lies within a shape.
cpBool PB_cpShapePointQuery(cpShape *shape, cpVect *p)
{
     return cpShapePointQuery(shape, *p);
}

// Name: (cpShapeNearestPointQuery)  Return Type: (cpFloat)  Arguments: (cpShape *shape, cpVect p, cpNearestPointQueryInfo *out)  - Perform a nearest point query. It finds the closest point on the surface of shape to a specific point.
/// Perform a nearest point query. It finds the closest point on the surface of shape to a specific point.
cpFloat PB_cpShapeNearestPointQuery(cpShape *shape, cpVect *p, cpNearestPointQueryInfo *out)
{
     return cpShapeNearestPointQuery(shape, *p, out);
}

// Name: (cpShapeSegmentQuery)  Return Type: (cpBool)  Arguments: (cpShape *shape, cpVect a, cpVect b, cpSegmentQueryInfo *info)  - Perform a segment query against a shape. info must be a pointer to a valid cpSegmentQueryInfo structure.
/// Perform a segment query against a shape. info must be a pointer to a valid cpSegmentQueryInfo structure.
cpBool PB_cpShapeSegmentQuery(cpShape *shape, cpVect *a, cpVect *b, cpSegmentQueryInfo *info)
{
     return cpShapeSegmentQuery(shape, *a, *b, info);
}

// Name: (cpSegmentQueryHitPoint)  Return Type: (cpVect)  Arguments: (cpVect start, cpVect end, cpSegmentQueryInfo info)  - Get the hit point for a segment query.
/// Get the hit point for a segment query.
void PB_cpSegmentQueryHitPoint(cpVect *result, cpVect *start, cpVect *end, cpSegmentQueryInfo *info)
{
     *result = cpSegmentQueryHitPoint(*start, *end, *info);
}

// Name: (cpSegmentQueryHitDist)  Return Type: (cpFloat)  Arguments: (cpVect start, cpVect end, cpSegmentQueryInfo info)  - Get the hit distance for a segment query.
/// Get the hit distance for a segment query.
cpFloat PB_cpSegmentQueryHitDist(cpVect *start, cpVect *end, cpSegmentQueryInfo *info)
{
     return cpSegmentQueryHitDist(*start, *end, *info);
}

// Name: (cpShapeSetBody)  Return Type: (void)  Arguments: (cpShape *shape, cpBody *body)  - 
/// 
void PB_cpShapeSetBody(cpShape *shape, cpBody *body)
{
     cpShapeSetBody(shape, body);
}

// Name: (cpResetShapeIdCounter)  Return Type: (void)  Arguments: (void)  - When initializing a shape, it's hash value comes from a counter.
/// When initializing a shape, it's hash value comes from a counter.
void PB_cpResetShapeIdCounter(void )
{
     cpResetShapeIdCounter();
}

// Name: (cpCircleShapeAlloc)  Return Type: (cpCircleShape*)  Arguments: (void)  - Allocate a circle shape.
/// Allocate a circle shape.
cpCircleShape* PB_cpCircleShapeAlloc(void )
{
     return cpCircleShapeAlloc();
}

// Name: (cpCircleShapeInit)  Return Type: (cpCircleShape*)  Arguments: (cpCircleShape *circle, cpBody *body, cpFloat radius, cpVect offset)  - Initialize a circle shape.
/// Initialize a circle shape.
cpCircleShape* PB_cpCircleShapeInit(cpCircleShape *circle, cpBody *body, cpFloat radius, cpVect *offset)
{
     return cpCircleShapeInit(circle, body, radius, *offset);
}

// Name: (cpCircleShapeNew)  Return Type: (cpShape*)  Arguments: (cpBody *body, cpFloat radius, cpVect offset)  - Allocate and initialize a circle shape.
/// Allocate and initialize a circle shape.
cpShape* PB_cpCircleShapeNew(cpBody *body, cpFloat radius, cpVect *offset)
{
     return cpCircleShapeNew(body, radius, *offset);
}

// Name: (cpSegmentShapeAlloc)  Return Type: (cpSegmentShape*)  Arguments: (void)  - Allocate a segment shape.
/// Allocate a segment shape.
cpSegmentShape* PB_cpSegmentShapeAlloc(void )
{
     return cpSegmentShapeAlloc();
}

// Name: (cpSegmentShapeInit)  Return Type: (cpSegmentShape*)  Arguments: (cpSegmentShape *seg, cpBody *body, cpVect a, cpVect b, cpFloat radius)  - Initialize a segment shape.
/// Initialize a segment shape.
cpSegmentShape* PB_cpSegmentShapeInit(cpSegmentShape *seg, cpBody *body, cpVect *a, cpVect *b, cpFloat radius)
{
     return cpSegmentShapeInit(seg, body, *a, *b, radius);
}

// Name: (cpSegmentShapeNew)  Return Type: (cpShape*)  Arguments: (cpBody *body, cpVect a, cpVect b, cpFloat radius)  - Allocate and initialize a segment shape.
/// Allocate and initialize a segment shape.
cpShape* PB_cpSegmentShapeNew(cpBody *body, cpVect *a, cpVect *b, cpFloat radius)
{
     return cpSegmentShapeNew(body, *a, *b, radius);
}

// Name: (cpSegmentShapeSetNeighbors)  Return Type: (void)  Arguments: (cpShape *shape, cpVect prev, cpVect next)  - 
/// 
void PB_cpSegmentShapeSetNeighbors(cpShape *shape, cpVect *prev, cpVect *next)
{
     cpSegmentShapeSetNeighbors(shape, *prev, *next);
}

// Name: (cpSpaceAlloc)  Return Type: (cpSpace*)  Arguments: (void)  - Allocate a cpSpace.
/// Allocate a cpSpace.
cpSpace* PB_cpSpaceAlloc(void )
{
     return cpSpaceAlloc();
}

// Name: (cpSpaceInit)  Return Type: (cpSpace*)  Arguments: (cpSpace *space)  - Initialize a cpSpace.
/// Initialize a cpSpace.
cpSpace* PB_cpSpaceInit(cpSpace *space)
{
     return cpSpaceInit(space);
}

// Name: (cpSpaceNew)  Return Type: (cpSpace*)  Arguments: (void)  - Allocate and initialize a cpSpace.
/// Allocate and initialize a cpSpace.
cpSpace* PB_cpSpaceNew(void )
{
     return cpSpaceNew();
}

// Name: (cpSpaceDestroy)  Return Type: (void)  Arguments: (cpSpace *space)  - Destroy a cpSpace.
/// Destroy a cpSpace.
void PB_cpSpaceDestroy(cpSpace *space)
{
     cpSpaceDestroy(space);
}

// Name: (cpSpaceFree)  Return Type: (void)  Arguments: (cpSpace *space)  - Destroy and free a cpSpace.
/// Destroy and free a cpSpace.
void PB_cpSpaceFree(cpSpace *space)
{
     cpSpaceFree(space);
}

// Name: (cpSpaceSetDefaultCollisionHandler)  Return Type: (void)  Arguments: ( cpSpace *space, cpCollisionBeginFunc begin, cpCollisionPreSolveFunc preSolve, cpCollisionPostSolveFunc postSolve, cpCollisionSeparateFunc separate, void *data)  - Set a default collision handler for this space.
/// Set a default collision handler for this space.
void PB_cpSpaceSetDefaultCollisionHandler(cpSpace *space, cpCollisionBeginFunc begin, cpCollisionPreSolveFunc preSolve, cpCollisionPostSolveFunc postSolve, cpCollisionSeparateFunc separate, void *data)
{
     cpSpaceSetDefaultCollisionHandler(space, begin, preSolve, postSolve, separate, data);
}

// Name: (cpSpaceAddCollisionHandler)  Return Type: (void)  Arguments: (cpSpace *space, cpCollisionType a, cpCollisionType b, cpCollisionBeginFunc begin, cpCollisionPreSolveFunc preSolve, cpCollisionPostSolveFunc postSolve, cpCollisionSeparateFunc separate, void *data)  - Set a collision handler to be used whenever the two shapes with the given collision types collide.
/// Set a collision handler to be used whenever the two shapes with the given collision types collide.
void PB_cpSpaceAddCollisionHandler(cpSpace *space, cpCollisionType a, cpCollisionType b, cpCollisionBeginFunc begin, cpCollisionPreSolveFunc preSolve, cpCollisionPostSolveFunc postSolve, cpCollisionSeparateFunc separate, void *data)
{
     cpSpaceAddCollisionHandler(space, a, b, begin, preSolve, postSolve, separate, data);
}

// Name: (cpSpaceRemoveCollisionHandler)  Return Type: (void)  Arguments: (cpSpace *space, cpCollisionType a, cpCollisionType b)  - Unset a collision handler.
/// Unset a collision handler.
void PB_cpSpaceRemoveCollisionHandler(cpSpace *space, cpCollisionType a, cpCollisionType b)
{
     cpSpaceRemoveCollisionHandler(space, a, b);
}

// Name: (cpSpaceAddShape)  Return Type: (cpShape*)  Arguments: (cpSpace *space, cpShape *shape)  - Add a collision shape to the simulation.
/// Add a collision shape to the simulation.
cpShape* PB_cpSpaceAddShape(cpSpace *space, cpShape *shape)
{
     return cpSpaceAddShape(space, shape);
}

// Name: (cpSpaceAddStaticShape)  Return Type: (cpShape*)  Arguments: (cpSpace *space, cpShape *shape)  - Explicity add a shape as a static shape to the simulation.
/// Explicity add a shape as a static shape to the simulation.
cpShape* PB_cpSpaceAddStaticShape(cpSpace *space, cpShape *shape)
{
     return cpSpaceAddStaticShape(space, shape);
}

// Name: (cpSpaceAddBody)  Return Type: (cpBody*)  Arguments: (cpSpace *space, cpBody *body)  - Add a rigid body to the simulation.
/// Add a rigid body to the simulation.
cpBody* PB_cpSpaceAddBody(cpSpace *space, cpBody *body)
{
     return cpSpaceAddBody(space, body);
}

// Name: (cpSpaceAddConstraint)  Return Type: (cpConstraint*)  Arguments: (cpSpace *space, cpConstraint *constraint)  - Add a constraint to the simulation.
/// Add a constraint to the simulation.
cpConstraint* PB_cpSpaceAddConstraint(cpSpace *space, cpConstraint *constraint)
{
     return cpSpaceAddConstraint(space, constraint);
}

// Name: (cpSpaceRemoveShape)  Return Type: (void)  Arguments: (cpSpace *space, cpShape *shape)  - Remove a collision shape from the simulation.
/// Remove a collision shape from the simulation.
void PB_cpSpaceRemoveShape(cpSpace *space, cpShape *shape)
{
     cpSpaceRemoveShape(space, shape);
}

// Name: (cpSpaceRemoveStaticShape)  Return Type: (void)  Arguments: (cpSpace *space, cpShape *shape)  - Remove a collision shape added using cpSpaceAddStaticShape() from the simulation.
/// Remove a collision shape added using cpSpaceAddStaticShape() from the simulation.
void PB_cpSpaceRemoveStaticShape(cpSpace *space, cpShape *shape)
{
     cpSpaceRemoveStaticShape(space, shape);
}

// Name: (cpSpaceRemoveBody)  Return Type: (void)  Arguments: (cpSpace *space, cpBody *body)  - Remove a rigid body from the simulation.
/// Remove a rigid body from the simulation.
void PB_cpSpaceRemoveBody(cpSpace *space, cpBody *body)
{
     cpSpaceRemoveBody(space, body);
}

// Name: (cpSpaceRemoveConstraint)  Return Type: (void)  Arguments: (cpSpace *space, cpConstraint *constraint)  - Remove a constraint from the simulation.
/// Remove a constraint from the simulation.
void PB_cpSpaceRemoveConstraint(cpSpace *space, cpConstraint *constraint)
{
     cpSpaceRemoveConstraint(space, constraint);
}

// Name: (cpSpaceContainsShape)  Return Type: (cpBool)  Arguments: (cpSpace *space, cpShape *shape)  - Test if a collision shape has been added to the space.
/// Test if a collision shape has been added to the space.
cpBool PB_cpSpaceContainsShape(cpSpace *space, cpShape *shape)
{
     return cpSpaceContainsShape(space, shape);
}

// Name: (cpSpaceContainsBody)  Return Type: (cpBool)  Arguments: (cpSpace *space, cpBody *body)  - Test if a rigid body has been added to the space.
/// Test if a rigid body has been added to the space.
cpBool PB_cpSpaceContainsBody(cpSpace *space, cpBody *body)
{
     return cpSpaceContainsBody(space, body);
}

// Name: (cpSpaceContainsConstraint)  Return Type: (cpBool)  Arguments: (cpSpace *space, cpConstraint *constraint)  - Test if a constraint has been added to the space.
/// Test if a constraint has been added to the space.
cpBool PB_cpSpaceContainsConstraint(cpSpace *space, cpConstraint *constraint)
{
     return cpSpaceContainsConstraint(space, constraint);
}

// Name: (cpSpaceAddPostStepCallback)  Return Type: (void)  Arguments: (cpSpace *space, cpPostStepFunc func, void *key, void *data)  - Schedule a post-step callback to be called when cpSpaceStep() finishes.
/// Schedule a post-step callback to be called when cpSpaceStep() finishes.
void PB_cpSpaceAddPostStepCallback(cpSpace *space, cpPostStepFunc func, void *key, void *data)
{
     cpSpaceAddPostStepCallback(space, func, key, data);
}

// Name: (cpSpacePointQuery)  Return Type: (void)  Arguments: (cpSpace *space, cpVect point, cpLayers layers, cpGroup group, cpSpacePointQueryFunc func, void *data)  - Query the space at a point and call func for each shape found.
/// Query the space at a point and call func for each shape found.
void PB_cpSpacePointQuery(cpSpace *space, cpVect *point, cpLayers layers, cpGroup group, cpSpacePointQueryFunc func, void *data)
{
     cpSpacePointQuery(space, *point, layers, group, func, data);
}

// Name: (cpSpaceNearestPointQuery)  Return Type: (void)  Arguments: (cpSpace *space, cpVect point, cpFloat maxDistance, cpLayers layers, cpGroup group, cpSpaceNearestPointQueryFunc func, void *data)  - Query the space at a point and call func for each shape found.
/// Query the space at a point and call func for each shape found.
void PB_cpSpaceNearestPointQuery(cpSpace *space, cpVect *point, cpFloat maxDistance, cpLayers layers, cpGroup group, cpSpaceNearestPointQueryFunc func, void *data)
{
     cpSpaceNearestPointQuery(space, *point, maxDistance, layers, group, func, data);
}

// Name: (cpSpaceSegmentQuery)  Return Type: (void)  Arguments: (cpSpace *space, cpVect start, cpVect end, cpLayers layers, cpGroup group, cpSpaceSegmentQueryFunc func, void *data)  - Perform a directed line segment query (like a raycast) against the space calling func for each shape intersected.
/// Perform a directed line segment query (like a raycast) against the space calling func for each shape intersected.
void PB_cpSpaceSegmentQuery(cpSpace *space, cpVect *start, cpVect *end, cpLayers layers, cpGroup group, cpSpaceSegmentQueryFunc func, void *data)
{
     cpSpaceSegmentQuery(space, *start, *end, layers, group, func, data);
}

// Name: (cpSpaceBBQuery)  Return Type: (void)  Arguments: (cpSpace *space, cpBB bb, cpLayers layers, cpGroup group, cpSpaceBBQueryFunc func, void *data)  - Perform a fast rectangle query on the space calling func for each shape found.
/// Perform a fast rectangle query on the space calling func for each shape found.
void PB_cpSpaceBBQuery(cpSpace *space, cpBB *bb, cpLayers layers, cpGroup group, cpSpaceBBQueryFunc func, void *data)
{
     cpSpaceBBQuery(space, *bb, layers, group, func, data);
}

// Name: (cpSpaceShapeQuery)  Return Type: (cpBool)  Arguments: (cpSpace *space, cpShape *shape, cpSpaceShapeQueryFunc func, void *data)  - Query a space for any shapes overlapping the given shape and call func for each shape found.
/// Query a space for any shapes overlapping the given shape and call func for each shape found.
cpBool PB_cpSpaceShapeQuery(cpSpace *space, cpShape *shape, cpSpaceShapeQueryFunc func, void *data)
{
     return cpSpaceShapeQuery(space, shape, func, data);
}

// Name: (cpSpaceActivateShapesTouchingShape)  Return Type: (void)  Arguments: (cpSpace *space, cpShape *shape)  - Call cpBodyActivate() for any shape that is overlaps the given shape.
/// Call cpBodyActivate() for any shape that is overlaps the given shape.
void PB_cpSpaceActivateShapesTouchingShape(cpSpace *space, cpShape *shape)
{
     cpSpaceActivateShapesTouchingShape(space, shape);
}

// Name: (cpSpaceEachBody)  Return Type: (void)  Arguments: (cpSpace *space, cpSpaceBodyIteratorFunc func, void *data)  - Call func for each body in the space.
/// Call func for each body in the space.
void PB_cpSpaceEachBody(cpSpace *space, cpSpaceBodyIteratorFunc func, void *data)
{
     cpSpaceEachBody(space, func, data);
}

// Name: (cpSpaceEachShape)  Return Type: (void)  Arguments: (cpSpace *space, cpSpaceShapeIteratorFunc func, void *data)  - Call func for each shape in the space.
/// Call func for each shape in the space.
void PB_cpSpaceEachShape(cpSpace *space, cpSpaceShapeIteratorFunc func, void *data)
{
     cpSpaceEachShape(space, func, data);
}

// Name: (cpSpaceEachConstraint)  Return Type: (void)  Arguments: (cpSpace *space, cpSpaceConstraintIteratorFunc func, void *data)  - Call func for each shape in the space.
/// Call func for each shape in the space.
void PB_cpSpaceEachConstraint(cpSpace *space, cpSpaceConstraintIteratorFunc func, void *data)
{
     cpSpaceEachConstraint(space, func, data);
}

// Name: (cpSpaceReindexStatic)  Return Type: (void)  Arguments: (cpSpace *space)  - Update the collision detection info for the static shapes in the space.
/// Update the collision detection info for the static shapes in the space.
void PB_cpSpaceReindexStatic(cpSpace *space)
{
     cpSpaceReindexStatic(space);
}

// Name: (cpSpaceReindexShape)  Return Type: (void)  Arguments: (cpSpace *space, cpShape *shape)  - Update the collision detection data for a specific shape in the space.
/// Update the collision detection data for a specific shape in the space.
void PB_cpSpaceReindexShape(cpSpace *space, cpShape *shape)
{
     cpSpaceReindexShape(space, shape);
}

// Name: (cpSpaceReindexShapesForBody)  Return Type: (void)  Arguments: (cpSpace *space, cpBody *body)  - Update the collision detection data for all shapes attached to a body.
/// Update the collision detection data for all shapes attached to a body.
void PB_cpSpaceReindexShapesForBody(cpSpace *space, cpBody *body)
{
     cpSpaceReindexShapesForBody(space, body);
}

// Name: (cpSpaceUseSpatialHash)  Return Type: (void)  Arguments: (cpSpace *space, cpFloat dim, int count)  - Switch the space to use a spatial has as it's spatial index.
/// Switch the space to use a spatial has as it's spatial index.
void PB_cpSpaceUseSpatialHash(cpSpace *space, cpFloat dim, int count)
{
     cpSpaceUseSpatialHash(space, dim, count);
}

// Name: (cpSpaceStep)  Return Type: (void)  Arguments: (cpSpace *space, cpFloat dt)  - Step the space forward in time by dt.
/// Step the space forward in time by dt.
void PB_cpSpaceStep(cpSpace *space, cpFloat dt)
{
     cpSpaceStep(space, dt);
}

// Name: (cpSpaceHashAlloc)  Return Type: (cpSpaceHash*)  Arguments: (void)  - Allocate a spatial hash.
/// Allocate a spatial hash.
cpSpaceHash* PB_cpSpaceHashAlloc(void )
{
     return cpSpaceHashAlloc();
}

// Name: (cpSpaceHashInit)  Return Type: (cpSpatialIndex*)  Arguments: (cpSpaceHash *hash, cpFloat celldim, int numcells, cpSpatialIndexBBFunc bbfunc, cpSpatialIndex *staticIndex)  - Initialize a spatial hash.
/// Initialize a spatial hash.
cpSpatialIndex* PB_cpSpaceHashInit(cpSpaceHash *hash, cpFloat celldim, int numcells, cpSpatialIndexBBFunc bbfunc, cpSpatialIndex *staticIndex)
{
     return cpSpaceHashInit(hash, celldim, numcells, bbfunc, staticIndex);
}

// Name: (cpSpaceHashNew)  Return Type: (cpSpatialIndex*)  Arguments: (cpFloat celldim, int cells, cpSpatialIndexBBFunc bbfunc, cpSpatialIndex *staticIndex)  - Allocate and initialize a spatial hash.
/// Allocate and initialize a spatial hash.
cpSpatialIndex* PB_cpSpaceHashNew(cpFloat celldim, int cells, cpSpatialIndexBBFunc bbfunc, cpSpatialIndex *staticIndex)
{
     return cpSpaceHashNew(celldim, cells, bbfunc, staticIndex);
}

// Name: (cpSpaceHashResize)  Return Type: (void)  Arguments: (cpSpaceHash *hash, cpFloat celldim, int numcells)  - Change the cell dimensions and table size of the spatial hash to tune it.
/// Change the cell dimensions and table size of the spatial hash to tune it.
void PB_cpSpaceHashResize(cpSpaceHash *hash, cpFloat celldim, int numcells)
{
     cpSpaceHashResize(hash, celldim, numcells);
}

// Name: (cpBBTreeAlloc)  Return Type: (cpBBTree*)  Arguments: (void)  - Allocate a bounding box tree.
/// Allocate a bounding box tree.
cpBBTree* PB_cpBBTreeAlloc(void )
{
     return cpBBTreeAlloc();
}

// Name: (cpBBTreeInit)  Return Type: (cpSpatialIndex*)  Arguments: (cpBBTree *tree, cpSpatialIndexBBFunc bbfunc, cpSpatialIndex *staticIndex)  - Initialize a bounding box tree.
/// Initialize a bounding box tree.
cpSpatialIndex* PB_cpBBTreeInit(cpBBTree *tree, cpSpatialIndexBBFunc bbfunc, cpSpatialIndex *staticIndex)
{
     return cpBBTreeInit(tree, bbfunc, staticIndex);
}

// Name: (cpBBTreeNew)  Return Type: (cpSpatialIndex*)  Arguments: (cpSpatialIndexBBFunc bbfunc, cpSpatialIndex *staticIndex)  - Allocate and initialize a bounding box tree.
/// Allocate and initialize a bounding box tree.
cpSpatialIndex* PB_cpBBTreeNew(cpSpatialIndexBBFunc bbfunc, cpSpatialIndex *staticIndex)
{
     return cpBBTreeNew(bbfunc, staticIndex);
}

// Name: (cpBBTreeOptimize)  Return Type: (void)  Arguments: (cpSpatialIndex *index)  - Perform a static top down optimization of the tree.
/// Perform a static top down optimization of the tree.
void PB_cpBBTreeOptimize(cpSpatialIndex *index)
{
     cpBBTreeOptimize(index);
}

// Name: (cpBBTreeSetVelocityFunc)  Return Type: (void)  Arguments: (cpSpatialIndex *index, cpBBTreeVelocityFunc func)  - Set the velocity function for the bounding box tree to enable temporal coherence.
/// Set the velocity function for the bounding box tree to enable temporal coherence.
void PB_cpBBTreeSetVelocityFunc(cpSpatialIndex *index, cpBBTreeVelocityFunc func)
{
     cpBBTreeSetVelocityFunc(index, func);
}

// Name: (cpSweep1DAlloc)  Return Type: (cpSweep1D*)  Arguments: (void)  - Allocate a 1D sort and sweep broadphase.
/// Allocate a 1D sort and sweep broadphase.
cpSweep1D* PB_cpSweep1DAlloc(void )
{
     return cpSweep1DAlloc();
}

// Name: (cpSweep1DInit)  Return Type: (cpSpatialIndex*)  Arguments: (cpSweep1D *sweep, cpSpatialIndexBBFunc bbfunc, cpSpatialIndex *staticIndex)  - Initialize a 1D sort and sweep broadphase.
/// Initialize a 1D sort and sweep broadphase.
cpSpatialIndex* PB_cpSweep1DInit(cpSweep1D *sweep, cpSpatialIndexBBFunc bbfunc, cpSpatialIndex *staticIndex)
{
     return cpSweep1DInit(sweep, bbfunc, staticIndex);
}

// Name: (cpSweep1DNew)  Return Type: (cpSpatialIndex*)  Arguments: (cpSpatialIndexBBFunc bbfunc, cpSpatialIndex *staticIndex)  - Allocate and initialize a 1D sort and sweep broadphase.
/// Allocate and initialize a 1D sort and sweep broadphase.
cpSpatialIndex* PB_cpSweep1DNew(cpSpatialIndexBBFunc bbfunc, cpSpatialIndex *staticIndex)
{
     return cpSweep1DNew(bbfunc, staticIndex);
}

// Name: (cpSpatialIndexFree)  Return Type: (void)  Arguments: (cpSpatialIndex *index)  - Destroy and free a spatial index.
/// Destroy and free a spatial index.
void PB_cpSpatialIndexFree(cpSpatialIndex *index)
{
     cpSpatialIndexFree(index);
}

// Name: (cpSpatialIndexCollideStatic)  Return Type: (void)  Arguments: (cpSpatialIndex *dynamicIndex, cpSpatialIndex *staticIndex, cpSpatialIndexQueryFunc func, void *data)  - Collide the objects in dynamicIndex against the objects in staticIndex using the query callback function.
/// Collide the objects in dynamicIndex against the objects in staticIndex using the query callback function.
void PB_cpSpatialIndexCollideStatic(cpSpatialIndex *dynamicIndex, cpSpatialIndex *staticIndex, cpSpatialIndexQueryFunc func, void *data)
{
     cpSpatialIndexCollideStatic(dynamicIndex, staticIndex, func, data);
}

// Name: (cpSpatialIndexDestroy)  Return Type: (void)  Arguments: (cpSpatialIndex *index)  - Destroy a spatial index.
/// Destroy a spatial index.
void PB_cpSpatialIndexDestroy(cpSpatialIndex *index)
{
     cpSpatialIndexDestroy(index);
}

// Name: (cpSpatialIndexCount)  Return Type: (int)  Arguments: (cpSpatialIndex *index)  - Get the number of objects in the spatial index.
/// Get the number of objects in the spatial index.
int PB_cpSpatialIndexCount(cpSpatialIndex *index)
{
     return cpSpatialIndexCount(index);
}

// Name: (cpSpatialIndexEach)  Return Type: (void)  Arguments: (cpSpatialIndex *index, cpSpatialIndexIteratorFunc func, void *data)  - Iterate the objects in the spatial index. func will be called once for each object.
/// Iterate the objects in the spatial index. func will be called once for each object.
void PB_cpSpatialIndexEach(cpSpatialIndex *index, cpSpatialIndexIteratorFunc func, void *data)
{
     cpSpatialIndexEach(index, func, data);
}

// Name: (cpSpatialIndexContains)  Return Type: (cpBool)  Arguments: (cpSpatialIndex *index, void *obj, cpHashValue hashid)  - Returns true if the spatial index contains the given object.
/// Returns true if the spatial index contains the given object.
cpBool PB_cpSpatialIndexContains(cpSpatialIndex *index, void *obj, cpHashValue *hashid)
{
     return cpSpatialIndexContains(index, obj, *hashid);
}

// Name: (cpSpatialIndexInsert)  Return Type: (void)  Arguments: (cpSpatialIndex *index, void *obj, cpHashValue hashid)  - Add an object to a spatial index.
/// Add an object to a spatial index.
void PB_cpSpatialIndexInsert(cpSpatialIndex *index, void *obj, cpHashValue *hashid)
{
     cpSpatialIndexInsert(index, obj, *hashid);
}

// Name: (cpSpatialIndexRemove)  Return Type: (void)  Arguments: (cpSpatialIndex *index, void *obj, cpHashValue hashid)  - Remove an object from a spatial index.
/// Remove an object from a spatial index.
void PB_cpSpatialIndexRemove(cpSpatialIndex *index, void *obj, cpHashValue *hashid)
{
     cpSpatialIndexRemove(index, obj, *hashid);
}

// Name: (cpSpatialIndexReindex)  Return Type: (void)  Arguments: (cpSpatialIndex *index)  - Perform a full reindex of a spatial index.
/// Perform a full reindex of a spatial index.
void PB_cpSpatialIndexReindex(cpSpatialIndex *index)
{
     cpSpatialIndexReindex(index);
}

// Name: (cpSpatialIndexReindexObject)  Return Type: (void)  Arguments: (cpSpatialIndex *index, void *obj, cpHashValue hashid)  - Reindex a single object in the spatial index.
/// Reindex a single object in the spatial index.
void PB_cpSpatialIndexReindexObject(cpSpatialIndex *index, void *obj, cpHashValue *hashid)
{
     cpSpatialIndexReindexObject(index, obj, *hashid);
}

// Name: (cpSpatialIndexQuery)  Return Type: (void)  Arguments: (cpSpatialIndex *index, void *obj, cpBB bb, cpSpatialIndexQueryFunc func, void *data)  - Perform a rectangle query against the spatial index, calling func for each potential match.
/// Perform a rectangle query against the spatial index, calling func for each potential match.
void PB_cpSpatialIndexQuery(cpSpatialIndex *index, void *obj, cpBB *bb, cpSpatialIndexQueryFunc func, void *data)
{
     cpSpatialIndexQuery(index, obj, *bb, func, data);
}

// Name: (cpSpatialIndexSegmentQuery)  Return Type: (void)  Arguments: (cpSpatialIndex *index, void *obj, cpVect a, cpVect b, cpFloat t_exit, cpSpatialIndexSegmentQueryFunc func, void *data)  - Perform a segment query against the spatial index, calling func for each potential match.
/// Perform a segment query against the spatial index, calling func for each potential match.
void PB_cpSpatialIndexSegmentQuery(cpSpatialIndex *index, void *obj, cpVect *a, cpVect *b, cpFloat t_exit, cpSpatialIndexSegmentQueryFunc func, void *data)
{
     cpSpatialIndexSegmentQuery(index, obj, *a, *b, t_exit, func, data);
}

// Name: (cpSpatialIndexReindexQuery)  Return Type: (void)  Arguments: (cpSpatialIndex *index, cpSpatialIndexQueryFunc func, void *data)  - Simultaneously reindex and find all colliding objects.
/// Simultaneously reindex and find all colliding objects.
void PB_cpSpatialIndexReindexQuery(cpSpatialIndex *index, cpSpatialIndexQueryFunc func, void *data)
{
     cpSpatialIndexReindexQuery(index, func, data);
}

// Name: (cpv)  Return Type: (cpVect)  Arguments: (cpFloat x, cpFloat y)  - Convenience constructor for cpVect structs.
/// Convenience constructor for cpVect structs.
void PB_cpv(cpVect *result, cpFloat x, cpFloat y)
{
     *result = cpv(x, y);
}

// Name: (cpvlength)  Return Type: (cpFloat)  Arguments: (cpVect v)  - Returns the length of v.
/// Returns the length of v.
cpFloat PB_cpvlength(cpVect *v)
{
     return cpvlength(*v);
}

// Name: (cpvslerp)  Return Type: (cpVect)  Arguments: (cpVect v1, cpVect v2, cpFloat t)  - Spherical linearly interpolate between v1 and v2.
/// Spherical linearly interpolate between v1 and v2.
void PB_cpvslerp(cpVect *result, cpVect *v1, cpVect *v2, cpFloat t)
{
     *result = cpvslerp(*v1, *v2, t);
}

// Name: (cpvslerpconst)  Return Type: (cpVect)  Arguments: (cpVect v1, cpVect v2, cpFloat a)  - Spherical linearly interpolate between v1 towards v2 by no more than angle a radians
/// Spherical linearly interpolate between v1 towards v2 by no more than angle a radians
void PB_cpvslerpconst(cpVect *result, cpVect *v1, cpVect *v2, cpFloat a)
{
     *result = cpvslerpconst(*v1, *v2, a);
}

// Name: (cpvforangle)  Return Type: (cpVect)  Arguments: (cpFloat a)  - Returns the unit length vector for the given angle (in radians).
/// Returns the unit length vector for the given angle (in radians).
void PB_cpvforangle(cpVect *result, cpFloat a)
{
     *result = cpvforangle(a);
}

// Name: (cpvtoangle)  Return Type: (cpFloat)  Arguments: (cpVect v)  - Returns the angular direction v is pointing in (in radians).
/// Returns the angular direction v is pointing in (in radians).
cpFloat PB_cpvtoangle(cpVect *v)
{
     return cpvtoangle(*v);
}

// Name: (cpveql)  Return Type: (cpBool)  Arguments: (cpVect v1, cpVect v2)  - Check if two vectors are equal. (Be careful when comparing floating point numbers!)
/// Check if two vectors are equal. (Be careful when comparing floating point numbers!)
cpBool PB_cpveql(cpVect *v1, cpVect *v2)
{
     return cpveql(*v1, *v2);
}

// Name: (cpvadd)  Return Type: (cpVect)  Arguments: (cpVect v1, cpVect v2)  - Add two vectors
/// Add two vectors
void PB_cpvadd(cpVect *result, cpVect *v1, cpVect *v2)
{
     *result = cpvadd(*v1, *v2);
}

// Name: (cpvsub)  Return Type: (cpVect)  Arguments: (cpVect v1, cpVect v2)  - Subtract two vectors.
/// Subtract two vectors.
void PB_cpvsub(cpVect *result, cpVect *v1, cpVect *v2)
{
     *result = cpvsub(*v1, *v2);
}

// Name: (cpvneg)  Return Type: (cpVect)  Arguments: (cpVect v)  - Negate a vector.
/// Negate a vector.
void PB_cpvneg(cpVect *result, cpVect *v)
{
     *result = cpvneg(*v);
}

// Name: (cpvmult)  Return Type: (cpVect)  Arguments: (cpVect v, cpFloat s)  - Scalar multiplication.
/// Scalar multiplication.
void PB_cpvmult(cpVect *result, cpVect *v, cpFloat s)
{
     *result = cpvmult(*v, s);
}

// Name: (cpvdot)  Return Type: (cpFloat)  Arguments: (cpVect v1, cpVect v2)  - Vector dot product.
/// Vector dot product.
cpFloat PB_cpvdot(cpVect *v1, cpVect *v2)
{
     return cpvdot(*v1, *v2);
}

// Name: (cpvcross)  Return Type: (cpFloat)  Arguments: (cpVect v1, cpVect v2)  - 2D vector cross product analog.
/// 2D vector cross product analog.
cpFloat PB_cpvcross(cpVect *v1, cpVect *v2)
{
     return cpvcross(*v1, *v2);
}

// Name: (cpvperp)  Return Type: (cpVect)  Arguments: (cpVect v)  - Returns a perpendicular vector. (90 degree rotation)
/// Returns a perpendicular vector. (90 degree rotation)
void PB_cpvperp(cpVect *result, cpVect *v)
{
     *result = cpvperp(*v);
}

// Name: (cpvrperp)  Return Type: (cpVect)  Arguments: (cpVect v)  - Returns a perpendicular vector. (-90 degree rotation)
/// Returns a perpendicular vector. (-90 degree rotation)
void PB_cpvrperp(cpVect *result, cpVect *v)
{
     *result = cpvrperp(*v);
}

// Name: (cpvproject)  Return Type: (cpVect)  Arguments: (cpVect v1, cpVect v2)  - Returns the vector projection of v1 onto v2.
/// Returns the vector projection of v1 onto v2.
void PB_cpvproject(cpVect *result, cpVect *v1, cpVect *v2)
{
     *result = cpvproject(*v1, *v2);
}

// Name: (cpvrotate)  Return Type: (cpVect)  Arguments: (cpVect v1, cpVect v2)  - Uses complex number multiplication to rotate v1 by v2. Scaling will occur if v1 is not a unit vector.
/// Uses complex number multiplication to rotate v1 by v2. Scaling will occur if v1 is not a unit vector.
void PB_cpvrotate(cpVect *result, cpVect *v1, cpVect *v2)
{
     *result = cpvrotate(*v1, *v2);
}

// Name: (cpvunrotate)  Return Type: (cpVect)  Arguments: (cpVect v1, cpVect v2)  - Inverse of cpvrotate().
/// Inverse of cpvrotate().
void PB_cpvunrotate(cpVect *result, cpVect *v1, cpVect *v2)
{
     *result = cpvunrotate(*v1, *v2);
}

// Name: (cpvlengthsq)  Return Type: (cpFloat)  Arguments: (cpVect v)  - Returns the squared length of v. Faster than cpvlength() when you only need to compare lengths.
/// Returns the squared length of v. Faster than cpvlength() when you only need to compare lengths.
cpFloat PB_cpvlengthsq(cpVect *v)
{
     return cpvlengthsq(*v);
}

// Name: (cpvlerp)  Return Type: (cpVect)  Arguments: (cpVect v1, cpVect v2, cpFloat t)  - Linearly interpolate between v1 and v2.
/// Linearly interpolate between v1 and v2.
void PB_cpvlerp(cpVect *result, cpVect *v1, cpVect *v2, cpFloat t)
{
     *result = cpvlerp(*v1, *v2, t);
}

// Name: (cpvnormalize)  Return Type: (cpVect)  Arguments: (cpVect v)  - Returns a normalized copy of v.
/// Returns a normalized copy of v.
void PB_cpvnormalize(cpVect *result, cpVect *v)
{
     *result = cpvnormalize(*v);
}

// Name: (cpvnormalize_safe)  Return Type: (cpVect)  Arguments: (cpVect v)  - Returns a normalized copy of v or cpvzero if v was already cpvzero. Protects against divide by zero errors.
/// Returns a normalized copy of v or cpvzero if v was already cpvzero. Protects against divide by zero errors.
void PB_cpvnormalize_safe(cpVect *result, cpVect *v)
{
     *result = cpvnormalize_safe(*v);
}

// Name: (cpvclamp)  Return Type: (cpVect)  Arguments: (cpVect v, cpFloat len)  - Clamp v to length len.
/// Clamp v to length len.
void PB_cpvclamp(cpVect *result, cpVect *v, cpFloat len)
{
     *result = cpvclamp(*v, len);
}

// Name: (cpvlerpconst)  Return Type: (cpVect)  Arguments: (cpVect v1, cpVect v2, cpFloat d)  - Linearly interpolate between v1 towards v2 by distance d.
/// Linearly interpolate between v1 towards v2 by distance d.
void PB_cpvlerpconst(cpVect *result, cpVect *v1, cpVect *v2, cpFloat d)
{
     *result = cpvlerpconst(*v1, *v2, d);
}

// Name: (cpvdist)  Return Type: (cpFloat)  Arguments: (cpVect v1, cpVect v2)  - Returns the distance between v1 and v2.
/// Returns the distance between v1 and v2.
cpFloat PB_cpvdist(cpVect *v1, cpVect *v2)
{
     return cpvdist(*v1, *v2);
}

// Name: (cpvdistsq)  Return Type: (cpFloat)  Arguments: (cpVect v1, cpVect v2)  - Returns the squared distance between v1 and v2. Faster than cpvdist() when you only need to compare distances.
/// Returns the squared distance between v1 and v2. Faster than cpvdist() when you only need to compare distances.
cpFloat PB_cpvdistsq(cpVect *v1, cpVect *v2)
{
     return cpvdistsq(*v1, *v2);
}

// Name: (cpvnear)  Return Type: (cpBool)  Arguments: (cpVect v1, cpVect v2, cpFloat dist)  - Returns true if the distance between v1 and v2 is less than dist.
/// Returns true if the distance between v1 and v2 is less than dist.
cpBool PB_cpvnear(cpVect *v1, cpVect *v2, cpFloat dist)
{
     return cpvnear(*v1, *v2, dist);
}

// Name: (cpConstraintDestroy)  Return Type: (void)  Arguments: (cpConstraint *constraint)  - Destroy a constraint.
/// Destroy a constraint.
void PB_cpConstraintDestroy(cpConstraint *constraint)
{
     cpConstraintDestroy(constraint);
}

// Name: (cpConstraintFree)  Return Type: (void)  Arguments: (cpConstraint *constraint)  - Destroy and free a constraint.
/// Destroy and free a constraint.
void PB_cpConstraintFree(cpConstraint *constraint)
{
     cpConstraintFree(constraint);
}

// Name: (cpDampedRotarySpringAlloc)  Return Type: (cpDampedRotarySpring*)  Arguments: (void)  - Allocate a damped rotary spring.
/// Allocate a damped rotary spring.
cpDampedRotarySpring* PB_cpDampedRotarySpringAlloc(void )
{
     return cpDampedRotarySpringAlloc();
}

// Name: (cpDampedRotarySpringInit)  Return Type: (cpDampedRotarySpring*)  Arguments: (cpDampedRotarySpring *joint, cpBody *a, cpBody *b, cpFloat restAngle, cpFloat stiffness, cpFloat damping)  - Initialize a damped rotary spring.
/// Initialize a damped rotary spring.
cpDampedRotarySpring* PB_cpDampedRotarySpringInit(cpDampedRotarySpring *joint, cpBody *a, cpBody *b, cpFloat restAngle, cpFloat stiffness, cpFloat damping)
{
     return cpDampedRotarySpringInit(joint, a, b, restAngle, stiffness, damping);
}

// Name: (cpDampedRotarySpringNew)  Return Type: (cpConstraint*)  Arguments: (cpBody *a, cpBody *b, cpFloat restAngle, cpFloat stiffness, cpFloat damping)  - Allocate and initialize a damped rotary spring.
/// Allocate and initialize a damped rotary spring.
cpConstraint* PB_cpDampedRotarySpringNew(cpBody *a, cpBody *b, cpFloat restAngle, cpFloat stiffness, cpFloat damping)
{
     return cpDampedRotarySpringNew(a, b, restAngle, stiffness, damping);
}

// Name: (cpDampedSpringAlloc)  Return Type: (cpDampedSpring*)  Arguments: (void)  - Allocate a damped spring.
/// Allocate a damped spring.
cpDampedSpring* PB_cpDampedSpringAlloc(void )
{
     return cpDampedSpringAlloc();
}

// Name: (cpDampedSpringInit)  Return Type: (cpDampedSpring*)  Arguments: (cpDampedSpring *joint, cpBody *a, cpBody *b, cpVect anchr1, cpVect anchr2, cpFloat restLength, cpFloat stiffness, cpFloat damping)  - Initialize a damped spring.
/// Initialize a damped spring.
cpDampedSpring* PB_cpDampedSpringInit(cpDampedSpring *joint, cpBody *a, cpBody *b, cpVect *anchr1, cpVect *anchr2, cpFloat restLength, cpFloat stiffness, cpFloat damping)
{
     return cpDampedSpringInit(joint, a, b, *anchr1, *anchr2, restLength, stiffness, damping);
}

// Name: (cpDampedSpringNew)  Return Type: (cpConstraint*)  Arguments: (cpBody *a, cpBody *b, cpVect anchr1, cpVect anchr2, cpFloat restLength, cpFloat stiffness, cpFloat damping)  - Allocate and initialize a damped spring.
/// Allocate and initialize a damped spring.
cpConstraint* PB_cpDampedSpringNew(cpBody *a, cpBody *b, cpVect *anchr1, cpVect *anchr2, cpFloat restLength, cpFloat stiffness, cpFloat damping)
{
     return cpDampedSpringNew(a, b, *anchr1, *anchr2, restLength, stiffness, damping);
}

// Name: (cpGearJointAlloc)  Return Type: (cpGearJoint*)  Arguments: (void)  - Allocate a gear joint.
/// Allocate a gear joint.
cpGearJoint* PB_cpGearJointAlloc(void )
{
     return cpGearJointAlloc();
}

// Name: (cpGearJointInit)  Return Type: (cpGearJoint*)  Arguments: (cpGearJoint *joint, cpBody *a, cpBody *b, cpFloat phase, cpFloat ratio)  - Initialize a gear joint.
/// Initialize a gear joint.
cpGearJoint* PB_cpGearJointInit(cpGearJoint *joint, cpBody *a, cpBody *b, cpFloat phase, cpFloat ratio)
{
     return cpGearJointInit(joint, a, b, phase, ratio);
}

// Name: (cpGearJointNew)  Return Type: (cpConstraint*)  Arguments: (cpBody *a, cpBody *b, cpFloat phase, cpFloat ratio)  - Allocate and initialize a gear joint.
/// Allocate and initialize a gear joint.
cpConstraint* PB_cpGearJointNew(cpBody *a, cpBody *b, cpFloat phase, cpFloat ratio)
{
     return cpGearJointNew(a, b, phase, ratio);
}

// Name: (cpGearJointSetRatio)  Return Type: (void)  Arguments: (cpConstraint *constraint, cpFloat value)  - Set the ratio of a gear joint.
/// Set the ratio of a gear joint.
void PB_cpGearJointSetRatio(cpConstraint *constraint, cpFloat value)
{
     cpGearJointSetRatio(constraint, value);
}

// Name: (cpGrooveJointAlloc)  Return Type: (cpGrooveJoint*)  Arguments: (void)  - Allocate a groove joint.
/// Allocate a groove joint.
cpGrooveJoint* PB_cpGrooveJointAlloc(void )
{
     return cpGrooveJointAlloc();
}

// Name: (cpGrooveJointInit)  Return Type: (cpGrooveJoint*)  Arguments: (cpGrooveJoint *joint, cpBody *a, cpBody *b, cpVect groove_a, cpVect groove_b, cpVect anchr2)  - Initialize a groove joint.
/// Initialize a groove joint.
cpGrooveJoint* PB_cpGrooveJointInit(cpGrooveJoint *joint, cpBody *a, cpBody *b, cpVect *groove_a, cpVect *groove_b, cpVect *anchr2)
{
     return cpGrooveJointInit(joint, a, b, *groove_a, *groove_b, *anchr2);
}

// Name: (cpGrooveJointNew)  Return Type: (cpConstraint*)  Arguments: (cpBody *a, cpBody *b, cpVect groove_a, cpVect groove_b, cpVect anchr2)  - Allocate and initialize a groove joint.
/// Allocate and initialize a groove joint.
cpConstraint* PB_cpGrooveJointNew(cpBody *a, cpBody *b, cpVect *groove_a, cpVect *groove_b, cpVect *anchr2)
{
     return cpGrooveJointNew(a, b, *groove_a, *groove_b, *anchr2);
}

// Name: (cpGrooveJointSetGrooveA)  Return Type: (void)  Arguments: (cpConstraint *constraint, cpVect value)  - Set endpoint a of a groove joint's groove
/// Set endpoint a of a groove joint's groove
void PB_cpGrooveJointSetGrooveA(cpConstraint *constraint, cpVect *value)
{
     cpGrooveJointSetGrooveA(constraint, *value);
}

// Name: (cpGrooveJointSetGrooveB)  Return Type: (void)  Arguments: (cpConstraint *constraint, cpVect value)  - Set endpoint b of a groove joint's groove
/// Set endpoint b of a groove joint's groove
void PB_cpGrooveJointSetGrooveB(cpConstraint *constraint, cpVect *value)
{
     cpGrooveJointSetGrooveB(constraint, *value);
}

// Name: (cpPinJointAlloc)  Return Type: (cpPinJoint*)  Arguments: (void)  - Allocate a pin joint.
/// Allocate a pin joint.
cpPinJoint* PB_cpPinJointAlloc(void )
{
     return cpPinJointAlloc();
}

// Name: (cpPinJointInit)  Return Type: (cpPinJoint*)  Arguments: (cpPinJoint *joint, cpBody *a, cpBody *b, cpVect anchr1, cpVect anchr2)  - Initialize a pin joint.
/// Initialize a pin joint.
cpPinJoint* PB_cpPinJointInit(cpPinJoint *joint, cpBody *a, cpBody *b, cpVect *anchr1, cpVect *anchr2)
{
     return cpPinJointInit(joint, a, b, *anchr1, *anchr2);
}

// Name: (cpPinJointNew)  Return Type: (cpConstraint*)  Arguments: (cpBody *a, cpBody *b, cpVect anchr1, cpVect anchr2)  - Allocate and initialize a pin joint.
/// Allocate and initialize a pin joint.
cpConstraint* PB_cpPinJointNew(cpBody *a, cpBody *b, cpVect *anchr1, cpVect *anchr2)
{
     return cpPinJointNew(a, b, *anchr1, *anchr2);
}

// Name: (cpPivotJointAlloc)  Return Type: (cpPivotJoint*)  Arguments: (void)  - Allocate a pivot joint
/// Allocate a pivot joint
cpPivotJoint* PB_cpPivotJointAlloc(void )
{
     return cpPivotJointAlloc();
}

// Name: (cpPivotJointInit)  Return Type: (cpPivotJoint*)  Arguments: (cpPivotJoint *joint, cpBody *a, cpBody *b, cpVect anchr1, cpVect anchr2)  - Initialize a pivot joint.
/// Initialize a pivot joint.
cpPivotJoint* PB_cpPivotJointInit(cpPivotJoint *joint, cpBody *a, cpBody *b, cpVect *anchr1, cpVect *anchr2)
{
     return cpPivotJointInit(joint, a, b, *anchr1, *anchr2);
}

// Name: (cpPivotJointNew)  Return Type: (cpConstraint*)  Arguments: (cpBody *a, cpBody *b, cpVect pivot)  - Allocate and initialize a pivot joint.
/// Allocate and initialize a pivot joint.
cpConstraint* PB_cpPivotJointNew(cpBody *a, cpBody *b, cpVect *pivot)
{
     return cpPivotJointNew(a, b, *pivot);
}

// Name: (cpPivotJointNew2)  Return Type: (cpConstraint*)  Arguments: (cpBody *a, cpBody *b, cpVect anchr1, cpVect anchr2)  - Allocate and initialize a pivot joint with specific anchors.
/// Allocate and initialize a pivot joint with specific anchors.
cpConstraint* PB_cpPivotJointNew2(cpBody *a, cpBody *b, cpVect *anchr1, cpVect *anchr2)
{
     return cpPivotJointNew2(a, b, *anchr1, *anchr2);
}

// Name: (cpRatchetJointAlloc)  Return Type: (cpRatchetJoint*)  Arguments: (void)  - Allocate a ratchet joint.
/// Allocate a ratchet joint.
cpRatchetJoint* PB_cpRatchetJointAlloc(void )
{
     return cpRatchetJointAlloc();
}

// Name: (cpRatchetJointInit)  Return Type: (cpRatchetJoint*)  Arguments: (cpRatchetJoint *joint, cpBody *a, cpBody *b, cpFloat phase, cpFloat ratchet)  - Initialize a ratched joint.
/// Initialize a ratched joint.
cpRatchetJoint* PB_cpRatchetJointInit(cpRatchetJoint *joint, cpBody *a, cpBody *b, cpFloat phase, cpFloat ratchet)
{
     return cpRatchetJointInit(joint, a, b, phase, ratchet);
}

// Name: (cpRatchetJointNew)  Return Type: (cpConstraint*)  Arguments: (cpBody *a, cpBody *b, cpFloat phase, cpFloat ratchet)  - Allocate and initialize a ratchet joint.
/// Allocate and initialize a ratchet joint.
cpConstraint* PB_cpRatchetJointNew(cpBody *a, cpBody *b, cpFloat phase, cpFloat ratchet)
{
     return cpRatchetJointNew(a, b, phase, ratchet);
}

// Name: (cpRotaryLimitJointAlloc)  Return Type: (cpRotaryLimitJoint*)  Arguments: (void)  - Allocate a damped rotary limit joint.
/// Allocate a damped rotary limit joint.
cpRotaryLimitJoint* PB_cpRotaryLimitJointAlloc(void )
{
     return cpRotaryLimitJointAlloc();
}

// Name: (cpRotaryLimitJointInit)  Return Type: (cpRotaryLimitJoint*)  Arguments: (cpRotaryLimitJoint *joint, cpBody *a, cpBody *b, cpFloat min, cpFloat max)  - Initialize a damped rotary limit joint.
/// Initialize a damped rotary limit joint.
cpRotaryLimitJoint* PB_cpRotaryLimitJointInit(cpRotaryLimitJoint *joint, cpBody *a, cpBody *b, cpFloat min, cpFloat max)
{
     return cpRotaryLimitJointInit(joint, a, b, min, max);
}

// Name: (cpRotaryLimitJointNew)  Return Type: (cpConstraint*)  Arguments: (cpBody *a, cpBody *b, cpFloat min, cpFloat max)  - Allocate and initialize a damped rotary limit joint.
/// Allocate and initialize a damped rotary limit joint.
cpConstraint* PB_cpRotaryLimitJointNew(cpBody *a, cpBody *b, cpFloat min, cpFloat max)
{
     return cpRotaryLimitJointNew(a, b, min, max);
}

// Name: (cpSimpleMotorAlloc)  Return Type: (cpSimpleMotor*)  Arguments: (void)  - Allocate a simple motor.
/// Allocate a simple motor.
cpSimpleMotor* PB_cpSimpleMotorAlloc(void )
{
     return cpSimpleMotorAlloc();
}

// Name: (cpSimpleMotorInit)  Return Type: (cpSimpleMotor*)  Arguments: (cpSimpleMotor *joint, cpBody *a, cpBody *b, cpFloat rate)  - initialize a simple motor.
/// initialize a simple motor.
cpSimpleMotor* PB_cpSimpleMotorInit(cpSimpleMotor *joint, cpBody *a, cpBody *b, cpFloat rate)
{
     return cpSimpleMotorInit(joint, a, b, rate);
}

// Name: (cpSimpleMotorNew)  Return Type: (cpConstraint*)  Arguments: (cpBody *a, cpBody *b, cpFloat rate)  - Allocate and initialize a simple motor.
/// Allocate and initialize a simple motor.
cpConstraint* PB_cpSimpleMotorNew(cpBody *a, cpBody *b, cpFloat rate)
{
     return cpSimpleMotorNew(a, b, rate);
}

// Name: (cpSlideJointAlloc)  Return Type: (cpSlideJoint*)  Arguments: (void)  - Allocate a slide joint.
/// Allocate a slide joint.
cpSlideJoint* PB_cpSlideJointAlloc(void )
{
     return cpSlideJointAlloc();
}

// Name: (cpSlideJointInit)  Return Type: (cpSlideJoint*)  Arguments: (cpSlideJoint *joint, cpBody *a, cpBody *b, cpVect anchr1, cpVect anchr2, cpFloat min, cpFloat max)  - Initialize a slide joint.
/// Initialize a slide joint.
cpSlideJoint* PB_cpSlideJointInit(cpSlideJoint *joint, cpBody *a, cpBody *b, cpVect *anchr1, cpVect *anchr2, cpFloat min, cpFloat max)
{
     return cpSlideJointInit(joint, a, b, *anchr1, *anchr2, min, max);
}

// Name: (cpSlideJointNew)  Return Type: (cpConstraint*)  Arguments: (cpBody *a, cpBody *b, cpVect anchr1, cpVect anchr2, cpFloat min, cpFloat max)  - Allocate and initialize a slide joint.
/// Allocate and initialize a slide joint.
cpConstraint* PB_cpSlideJointNew(cpBody *a, cpBody *b, cpVect *anchr1, cpVect *anchr2, cpFloat min, cpFloat max)
{
     return cpSlideJointNew(a, b, *anchr1, *anchr2, min, max);
}
