; tool for producing a wrapper in PureBasic code for the Chipmunk library
; uses (hand prepared) chipmunk sources as input
; by eso, who apologizes profusely
; this is terrible code.

Global IntType.s
Global FloatType.s


CompilerSelect #PB_Compiler_Processor
  CompilerCase #PB_Processor_x86
    IntType.s = "Long"
    ; MacOS is special here because its CGPoint structure is floats on x86, doubles on x64
    CompilerIf #PB_Compiler_OS = #PB_OS_MacOS
      FloatType.s = "Float"      
    ; Everyone else uses doubles, since there's no OS level structures to match for vectors
    CompilerElse
      FloatType.s = "Double"
    CompilerEndIf
    
  CompilerCase #PB_Processor_x64
    ; on x64, everyone uses quads and doubles. Yay consistency.
    IntType.s = "Quad"
    FloatType.s = "Double"
CompilerEndSelect


ImportC ""
  pb_pcre_exec(*pcre,*extra,subject.s,length.i,startoffset.i,options.i,*ovector,ovecsize.i)
  pb_pcre_get_substring(subject.s, *ovector, stringcount.i, stringnumber.i, stringptr)
  pb_pcre_free_substring(stringptr)
EndImport


regexp_handle.i = CreateRegularExpression(#PB_Any, ".*?((static inline )?(\w*\*?)\s(cp\w*)\((.*?)\))", #PB_RegularExpression_AnyNewLine)
inputname.s = OpenFileRequester("File to scan:","","*.*",0)
inputhandle.i = ReadFile(#PB_Any,inputname)
exit.i = 0
linecount = 0
matchcount = 0
Dim pcre_results(18)
NewList CommentLines.s()

; This is a helper function to keep from having to screw around with manual offset crap, and to avoid having to
; handle freeing the temporary string pcre hands us.
Procedure.s get_substring(string.s, *ovector, resultcount, stringnumber)
  Define outputstring.s, stringptr.i
  pb_pcre_get_substring(string, *ovector, resultcount, stringnumber, @stringptr)
  outputstring= PeekS(stringptr, -1, #PB_UTF8)
  pb_pcre_free_substring(stringptr)
  ProcedureReturn outputstring
EndProcedure


; this ugly thing helps decide whether or not a pointer is needed for a particular
; type of data
; expects a C data type
Procedure.i needspointer(input.s)
  Select input
    Case "cpFloat", "int", "void", "cpLayers", "cpGroup", "cpBool", "cpCollisionType", "cpArbiterState", "cpShapeType"
      needpointer = 0
    Default
      If Right(input,4) = "Func"
        needpointer = 0
      Else
        needpointer = 1
      EndIf
  EndSelect
  ProcedureReturn needpointer
EndProcedure

; this ugly thing guesses whether or not the input already is a pointer
; expects the name of a C argument/return type
Procedure isapointer(input.s)
  If FindString(input, "**")
    ispointer = 2
  Else
    If FindString(input, "*")
      ispointer = 1
    Else
      ispointer = 0
    EndIf
  EndIf
  ProcedureReturn ispointer
EndProcedure

; this tries to do translation between C data types and the data types used
; in PureBasic in the .desc file.
; It's probably wrong, but getting seemingly-right answers so far.
Procedure.s DescType(argtype.s, argname.s)
  result.s = ""
  ispointer = isapointer(argname)
  If needspointer(argtype) Or ispointer
    result = IntType
  Else
    Select argtype
      Case "cpFloat"
        result = FloatType
      Case "int", "cpLayers", "cpTimeStamp"
        result = "quad"
      Default
        result = IntType   ; This seems too simplistic. I'm dubious, but can't find a reason for it to fail.
    EndSelect
  EndIf
  ProcedureReturn result
EndProcedure



If inputhandle
  outputCname.s = OpenFileRequester("Output C file:","shim.c","*.c",0)
  outputChandle.i = CreateFile(#PB_Any, outputCname)
  If outputChandle
    outputDname.s = OpenFileRequester("Output desc file:","shim.desc","*.desc",0)
    outputDhandle.i = CreateFile(#PB_Any, outputDname)
    If Not outputDhandle
      End
    EndIf
  Else
    End
  EndIf
Else
  End
EndIf

WriteStringN(outputChandle, "#include "+ #DQUOTE$ + "chipmunk.h" + #DQUOTE$)
WriteStringN(outputChandle, "")

WriteStringN(outputDhandle, "  ; Langage used to code the library: ASM or C")
WriteStringN(outputDhandle, "C")
WriteStringN(outputDhandle, "  ; Number of windows DLL than the library need")
WriteStringN(outputDhandle, "0")
WriteStringN(outputDhandle, "; Library type (Can be OBJ or LIB).")
WriteStringN(outputDhandle, "LIB")
WriteStringN(outputDhandle, "  ; Number of PureBasic library needed by the library.")
WriteStringN(outputDhandle, "0")
WriteStringN(outputDhandle, "  ; Help directory name.")
WriteStringN(outputDhandle, "chipmunk")
WriteStringN(outputDhandle, "  ; Library functions:")
WriteStringN(outputDhandle, "")

Repeat
  nextline.s = ReadString(inputhandle)
  
  linecount = linecount + 1
  If Eof(inputhandle)
    exit = 1
  EndIf
  string.s = nextline
  string = ReplaceString(string, #TAB$, "")
  Select Left(string,1)
    Case "#"               ; on the off chance the input file contains defines, discard them
      Continue
    Case "/"
      If Left(string,3) = "///"
        AddElement(CommentLines())
        CommentLines() = string
      EndIf
    Default
      resultcount.i = pb_pcre_exec(PeekL(regexp_handle),0,string,Len(string),0,0,@pcre_results(),18) 
      If resultcount > 0
        returntype.s = get_substring(string, @pcre_results(), resultcount, 3)
        If returntype = "return" Or returntype = ""   ; macros, and inline function bodies sometimes match, we discard those too
          ClearList(CommentLines())
          Continue
        Else
          functionname.s = get_substring(string, @pcre_results(), resultcount, 4)
          arguments.s = ReplaceString (get_substring(string, @pcre_results(), resultcount, 5),"const ","")
          If ListSize(CommentLines()) > 0  ; some functions have no documented comment.
            FirstElement(CommentLines())
            comment.s = Trim(ReplaceString(ReplaceString(CommentLines(),"@c ",""),"///",""))
            ClearList(CommentLines())
          Else
            comment = ""
          EndIf
          
          descriptorline.s = "Name: (" + functionname + ")  Return Type: (" + returntype + ")  Arguments: (" + arguments +")" + "  - " + comment
          WriteStringN(outputChandle, "")
          WriteStringN(outputChandle, "// " + descriptorline)
          WriteStringN(outputDhandle, "; " + descriptorline)
          WriteString(outputDhandle, functionname)
          PBarguments.s = ""
          PBdescription.s = ""
          outerarguments.s = ""
          innerarguments.s = ""
          adjustedreturn.i = 0
          Define innername.s, outername.s, ispointer.i, needpointer.i
          
          argumentcount = CountString(arguments, ",") + 1
          For i = 1 To argumentcount
            ThisArgument.s = Trim(StringField(arguments, i, ","))
            ArgumentType.s = Trim(StringField(ThisArgument, 1, " "))
            ArgumentName.s = Trim(StringField(ThisArgument, 2, " "))
            
            ispointer = isapointer(ArgumentName)
            needpointer = needspointer(ArgumentType)
            
            If needpointer And ispointer
              outername = ArgumentName
              innername = Trim(ArgumentName,"*")
              ; PB needs a pointer, CP already has pointer
            EndIf
            If needpointer And Not ispointer
              outername = "*" + ArgumentName
              innername = "*" + ArgumentName
              ;PB needs a pointer, CP does not
            EndIf
            If Not needpointer And ispointer
              outername = ArgumentName
              innername = Trim(ArgumentName,"*")
              ;CP uses a pointer, PB doesn't care
            EndIf
            If Not needpointer And Not ispointer
              outername = ArgumentName
              innername = ArgumentName
              ;Not a pointer, no pointer needed
            EndIf
            
            outerarguments = outerarguments + ", " + ArgumentType + " " + OuterName
            innerarguments = innerarguments + ", " + innername
            
            If ArgumentType <> "void" Or ArgumentName <> ""
              PBarguments = PBarguments + ", " + DescType(ArgumentType,ArgumentName)
              
              PBdescription = PBdescription + ", " + outername
            EndIf
          
            
          Next i
          
          outerarguments = Right(outerarguments, Len(outerarguments) - 2)
          innerarguments = Right(innerarguments, Len(innerarguments) - 2)
          PBdescription = Right(PBdescription, Len(PBdescription) - 2)
          
          
          If needspointer(returntype) And Not (isapointer(returntype))
            outerarguments = returntype + " *result, "+ outerarguments
            adjustedreturn = 1
            returntype = "void"
            PBarguments = ", " + IntType + PBarguments
            PBdescription = "*result, " + PBdescription
          EndIf
          
          PBdescription = " (" + PBdescription + ") - " + comment
          

          WriteStringN(outputChandle, "/// " + comment)
          WriteStringN(outputChandle, returntype + " PB_" + functionname + "(" + outerarguments + ")")
          WriteStringN(outputChandle, "{")
          If returntype = "void"
            If adjustedreturn
              WriteStringN(outputChandle, "     *result = " + functionname + "(" + innerarguments +");")
            Else
              WriteStringN(outputChandle, "     " + functionname + "(" + innerarguments +");")
            EndIf
            WriteStringN(outputDhandle, PBarguments + PBdescription)
            WriteStringN(outputDhandle, "None | CDecl")
          Else
            WriteStringN(outputChandle, "     return " + functionname + "(" + innerarguments +");")
            
            WriteStringN(outputDhandle, PBarguments + PBdescription)
            WriteStringN(outputDhandle, DescType(returntype, returntype)+ " | CDecl")
          EndIf
          WriteStringN(outputChandle, "}")
          
          
          
          matchcount = matchcount + 1
          
        EndIf
      EndIf
      If resultcount < 0
        ClearList(CommentLines())
      EndIf
      ; Case that is not checked: If resultcount = 0
      ; This is unlikely, since it'd require more results to occur from a single line than can fit in the pcre_results array. 
  EndSelect
Until exit

;    Debug linecount
;    Debug matchcount


; IDE Options = PureBasic 5.00 Beta 3 (Windows - x86)
; CursorPosition = 178
; FirstLine = 153
; Folding = -
; EnableXP
; CurrentDirectory = C:\Users\void\Dropbox\
; CompileSourceDirectory